@@ -1,8 +1,3 @@
-try:
-    from cPickle import dumps, loads
-except ImportError:
-    from pickle import dumps, loads
-
 from datetime import datetime, timedelta
 import logging
 import re
@@ -11,6 +6,7 @@ import struct
 import threading
 from urllib import splitport
 import zlib
+from io import BytesIO
 
 from bmemcached.exceptions import AuthenticationNotSupported, InvalidCredentials, MemcachedException
 
@@ -71,7 +67,9 @@ class Protocol(threading.local):
 
     COMPRESSION_THRESHOLD = 128
 
-    def __init__(self, server, username=None, password=None, compression=None):
+    def __init__(self, server, username=None, password=None, compression=None,
+                 socket_timeout=None, pickleProtocol=0,
+                 pickler=None, unpickler=None):
         self.server = server
         self._username = username
         self._password = password
@@ -79,6 +77,10 @@ class Protocol(threading.local):
         self.compression = zlib if compression is None else compression
         self.connection = None
         self.authenticated = False
+        self.socket_timeout = socket_timeout
+        self.pickleProtocol = pickleProtocol
+        self.pickler = pickler
+        self.unpickler = unpickler
 
         self.reconnects_deferred_until = None
 
@@ -109,6 +111,7 @@ class Protocol(threading.local):
         try:
             if self.host:
                 self.connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                self.connection.settimeout(self.socket_timeout)
                 self.connection.connect((self.host, self.port))
             else:
                 self.connection = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
@@ -301,7 +304,10 @@ class Protocol(threading.local):
             value = str(value)
         else:
             flags |= self.FLAGS['pickle']
-            value = dumps(value)
+            buf = BytesIO()
+            pickler = self.pickler(buf, self.pickleProtocol)
+            pickler.dump(value)
+            value = buf.getvalue()
 
         if len(value) > self.COMPRESSION_THRESHOLD:
             value = self.compression.compress(value)
@@ -328,7 +334,9 @@ class Protocol(threading.local):
         elif flags & self.FLAGS['long']:
             return long(value)
         elif flags & self.FLAGS['pickle']:
-            return loads(value)
+            buf = BytesIO(value)
+            unpickler = self.unpickler(buf)
+            return unpickler.load()
 
         return value
 
